@@ -178,7 +178,7 @@ densityplot.numeric <-
 
 densityplot.formula <-
     function(x,
-             data = parent.frame(),
+             data = NULL,
              allow.multiple = is.null(groups) || outer,
              outer = !is.null(groups),
 ##              allow.multiple = is.null(groups) || outer,
